@@ -11,3 +11,8 @@ class Schema(BaseModel):
     id: Optional[str]
     created_at: Optional[FirestoreTimestamp]
     updated_at: Optional[FirestoreTimestamp]
+
+
+class SchemaWithOwner(Schema):
+    created_by: Optional[str]
+    updated_by: Optional[str]
